Introduction
============

What is Karaage?
----------------
Karaage is a cluster account management tool. It can manage users and projects in a cluster and can store the data in various backends.

.. note::

    You may think this documentation this documentation is largely incomplete. You might or may not be correct.
